==> request-tracker4_4.4.6+dfsg.orig-third-party-source.tar.gz: rt-4.4.6/devel/third-party/ckeditor-src/plugins/link/lang/ar.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'link', 'ar', {
	acccessKey: 'مفاتيح الإختصار',
	advanced: 'متقدم',
	advisoryContentType: 'نوع التقرير',
	advisoryTitle: 'عنوان التقرير',
	anchor: {
		toolbar: 'إشارة مرجعية',
		menu: 'تحرير الإشارة المرجعية',
		title: 'خصائص الإشارة المرجعية',
		name: 'اسم الإشارة المرجعية',
		errorName: 'الرجاء كتابة اسم الإشارة المرجعية',
		remove: 'إزالة الإشارة المرجعية'
	},
	anchorId: 'حسب رقم العنصر',
	anchorName: 'حسب إسم الإشارة المرجعية',
	charset: 'ترميز المادة المطلوبة',
	cssClasses: 'فئات التنسيق',
	emailAddress: 'البريد الإلكتروني',
	emailBody: 'محتوى الرسالة',
	emailSubject: 'موضوع الرسالة',
	id: 'هوية',
	info: 'معلومات الرابط',
	langCode: 'رمز اللغة',
	langDir: 'إتجاه نص اللغة',
	langDirLTR: 'اليسار لليمين (LTR)',
	langDirRTL: 'اليمين لليسار (RTL)',
	menu: 'تحرير الرابط',
	name: 'إسم',
	noAnchors: '(لا توجد علامات مرجعية في هذا المستند)',
	noEmail: 'الرجاء كتابة الريد الإلكتروني',
	noUrl: 'الرجاء كتابة رابط الموقع',
	other: '<أخرى>',
	popupDependent: 'تابع (Netscape)',
	popupFeatures: 'خصائص النافذة المنبثقة',
	popupFullScreen: 'ملئ الشاشة (IE)',
	popupLeft: 'التمركز لليسار',
	popupLocationBar: 'شريط العنوان',
	popupMenuBar: 'القوائم الرئيسية',
	popupResizable: 'قابلة التشكيل',
	popupScrollBars: 'أشرطة التمرير',
	popupStatusBar: 'شريط الحالة',
	popupToolbar: 'شريط الأدوات',
	popupTop: 'التمركز للأعلى',
	rel: 'العلاقة',
	selectAnchor: 'اختر علامة مرجعية',
	styles: 'نمط',
	tabIndex: 'الترتيب',
	target: 'هدف الرابط',
	targetFrame: '<إطار>',
	targetFrameName: 'اسم الإطار المستهدف',
	targetPopup: '<نافذة منبثقة>',
	targetPopupName: 'اسم النافذة المنبثقة',
	title: 'رابط',
	toAnchor: 'مكان في هذا المستند',
	toEmail: 'بريد إلكتروني',
	toUrl: 'الرابط',
	toolbar: 'رابط',
	type: 'نوع الربط',
	unlink: 'إزالة رابط',
	upload: 'رفع'
} );

==> request-tracker5_5.0.1+dfsg.orig-third-party-source.tar.gz: rt-5.0.1/devel/third-party/ckeditor-src/plugins/link/lang/ar.js <==
﻿/*
Copyright (c) 2003-2019, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'ar', {
	acccessKey: 'مفاتيح الإختصار',
	advanced: 'متقدم',
	advisoryContentType: 'نوع التقرير',
	advisoryTitle: 'عنوان التقرير',
	anchor: {
		toolbar: 'إشارة مرجعية',
		menu: 'تحرير الإشارة المرجعية',
		title: 'خصائص الإشارة المرجعية',
		name: 'اسم الإشارة المرجعية',
		errorName: 'الرجاء كتابة اسم الإشارة المرجعية',
		remove: 'إزالة الإشارة المرجعية'
	},
	anchorId: 'حسب رقم العنصر',
	anchorName: 'حسب إسم الإشارة المرجعية',
	charset: 'ترميز المادة المطلوبة',
	cssClasses: 'فئات التنسيق',
	download: 'فرض التحميل',
	displayText: 'نص العرض',
	emailAddress: 'البريد الإلكتروني',
	emailBody: 'محتوى الرسالة',
	emailSubject: 'موضوع الرسالة',
	id: 'هوية',
	info: 'معلومات الرابط',
	langCode: 'رمز اللغة',
	langDir: 'إتجاه نص اللغة',
	langDirLTR: 'اليسار لليمين (LTR)',
	langDirRTL: 'اليمين لليسار (RTL)',
	menu: 'تحرير الرابط',
	name: 'إسم',
	noAnchors: '(لا توجد علامات مرجعية في هذا المستند)',
	noEmail: 'الرجاء كتابة الريد الإلكتروني',
	noUrl: 'الرجاء كتابة رابط الموقع',
	noTel: 'Please type the phone number', // MISSING
	other: '<أخرى>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'تابع (Netscape)',
	popupFeatures: 'خصائص النافذة المنبثقة',
	popupFullScreen: 'ملئ الشاشة (IE)',
	popupLeft: 'التمركز لليسار',
	popupLocationBar: 'شريط العنوان',
	popupMenuBar: 'القوائم الرئيسية',
	popupResizable: 'قابلة التشكيل',
	popupScrollBars: 'أشرطة التمرير',
	popupStatusBar: 'شريط الحالة',
	popupToolbar: 'شريط الأدوات',
	popupTop: 'التمركز للأعلى',
	rel: 'العلاقة',
	selectAnchor: 'اختر علامة مرجعية',
	styles: 'نمط',
	tabIndex: 'الترتيب',
	target: 'هدف الرابط',
	targetFrame: '<إطار>',
	targetFrameName: 'اسم الإطار المستهدف',
	targetPopup: '<نافذة منبثقة>',
	targetPopupName: 'اسم النافذة المنبثقة',
	title: 'رابط',
	toAnchor: 'مكان في هذا المستند',
	toEmail: 'بريد إلكتروني',
	toUrl: 'الرابط',
	toPhone: 'Phone', // MISSING
	toolbar: 'رابط',
	type: 'نوع الربط',
	unlink: 'إزالة رابط',
	upload: 'رفع'
} );
